pub struct Output {
pub amount: u64,
pub script: Script,
pub redeem_script: Option<Script>,
pub witness_script: Option<Script>,
pub bip32_derivation: BTreeMap<PublicKey, KeySource>,
pub tap_internal_key: Option<XOnlyPublicKey>,
pub tap_tree: Option<TapTree>,
pub tap_key_origins: BTreeMap<XOnlyPublicKey, (Vec<TapLeafHash>, KeySource)>,
pub proprietary: BTreeMap<ProprietaryKey, Vec<u8>>,
pub unknown: BTreeMap<Key, Vec<u8>>,
/* private fields */
}Fields
amount: u64The output’s amount in satoshis.
script: ScriptThe script for this output, also known as the scriptPubKey.
redeem_script: Option<Script>The redeem script for this output.
witness_script: Option<Script>The witness script for this output.
bip32_derivation: BTreeMap<PublicKey, KeySource>A map from public keys needed to spend this output to their corresponding master key fingerprints and derivation paths.
tap_internal_key: Option<XOnlyPublicKey>The internal pubkey.
tap_tree: Option<TapTree>Taproot Output tree.
tap_key_origins: BTreeMap<XOnlyPublicKey, (Vec<TapLeafHash>, KeySource)>Map of tap root x only keys to origin info and leaf hashes contained in it.
proprietary: BTreeMap<ProprietaryKey, Vec<u8>>Proprietary key-value pairs for this output.
unknown: BTreeMap<Key, Vec<u8>>Unknown key-value pairs for this output.
Implementations
sourceimpl Output
impl Output
sourcepub fn can_host_tapret(&self) -> bool
pub fn can_host_tapret(&self) -> bool
Returns whether this output may contain tapret commitment. This is
detected by the presence of PSBT_OUT_TAPRET_HOST key.
sourcepub fn tapret_dfs_path(&self) -> Option<Result<DfsPath, DfsPathEncodeError>>
pub fn tapret_dfs_path(&self) -> Option<Result<DfsPath, DfsPathEncodeError>>
Returns information on the specific path within taproot script tree
which is allowed as a place for tapret commitment. The path is taken
from PSBT_OUT_TAPRET_HOST key.
Returns
A value of the PSBT_OUT_TAPRET_HOST key, if present, or None
otherwise. The value is deserialized from the key value data, and if
the serialization fails a Some(Err(DfsPathEncodeError)) is
returned.
sourcepub fn set_tapret_dfs_path(&mut self, path: &DfsPath)
pub fn set_tapret_dfs_path(&mut self, path: &DfsPath)
Sets information on the specific path within taproot script tree which
is allowed as a place for tapret commitment. The path is put into
PSBT_OUT_TAPRET_HOST key.
sourcepub fn has_tapret_commitment(&self) -> bool
pub fn has_tapret_commitment(&self) -> bool
Detects presence of a vaid PSBT_OUT_TAPRET_COMMITMENT.
If PSBT_OUT_TAPRET_COMMITMENT is absent or its value is invalid,
returns false. In the future, when PSBT_OUT_TAPRET_COMMITMENT will
become a standard and non-custom key, PSBTs with invalid key values
will error at deserialization and this function will return false
only in cases when the output does not have
PSBT_OUT_TAPRET_COMMITMENT.
sourcepub fn tapret_commitment(&self) -> Option<Slice32>
pub fn tapret_commitment(&self) -> Option<Slice32>
Returns valid tapret commitment from the PSBT_OUT_TAPRET_COMMITMENT
key, if present. If the commitment is absent or invalid, returns
None.
We do not error on invalid commitments in order to support future update
of this proprietary key to the standard one. In this case, the
invalid commitments (having non-32 bytes) will be filtered at the
moment of PSBT deserialization and this function will return None
only in situations when the commitment is absent.
sourcepub fn set_tapret_commitment(
&mut self,
commitment: impl Into<[u8; 32]>
) -> Result<(), KeyError>
pub fn set_tapret_commitment(
&mut self,
commitment: impl Into<[u8; 32]>
) -> Result<(), KeyError>
Assigns value of the tapreturn commitment to this PSBT output, by
adding PSBT_OUT_TAPRET_COMMITMENT proprietary key containing the
32-byte commitment as its value.
Errors with KeyError::OutputAlreadyHasCommitment if the commitment
is already present in the output.
sourcepub fn has_tapret_proof(&self) -> bool
pub fn has_tapret_proof(&self) -> bool
Detects presence of a valid PSBT_OUT_TAPRET_PROOF.
If PSBT_OUT_TAPRET_PROOF is absent or its value is invalid,
returns false. In the future, when PSBT_OUT_TAPRET_PROOF will
become a standard and non-custom key, PSBTs with invalid key values
will error at deserialization and this function will return false
only in cases when the output does not have PSBT_OUT_TAPRET_PROOF.
sourcepub fn tapret_proof(&self) -> Option<TaprootMerkleBranch>
pub fn tapret_proof(&self) -> Option<TaprootMerkleBranch>
Returns valid tapret commitment proof from the PSBT_OUT_TAPRET_PROOF
key, if present. If the commitment is absent or invalid, returns None.
We do not error on invalid proofs in order to support future update of
this proprietary key to the standard one. In this case, the invalid
commitments (having non-32 bytes) will be filtered at the moment of PSBT
deserialization and this function will return None only in situations
when the commitment is absent.